export declare namespace Qiita {
    interface Error {
        /** エラーの内容を説明する文字列です */
        message: string;
        /** エラーの種類を表す文字列です */
        type: string;
    }
    interface Like {
        /** データが作成された日時 */
        created_at: string;
        /** Qiita上のユーザを表します。 */
        user: User;
    }
    interface AccessToken {
        /** 登録されたAPIクライアントを特定するためのIDです。40桁の16進数で表現されます。 */
        client_id: string;
        /** アプリケーションが利用するスコープをスペース区切りで指定できます。 */
        scopes: string[];
        /** CSRF対策のため、認可後にリダイレクトするURLのクエリに含まれる値を指定できます。 */
        token: string;
    }
    interface Group {
        /** データが作成された日時 */
        created_at: string;
        /** グループの一意なIDを表します。 */
        id: number;
        /** グループに付けられた表示用の名前を表します。 */
        name: string;
        /** 非公開グループかどうかを表します。 */
        private: boolean;
        /** データが最後に更新された日時 */
        updated_at: string;
        /** グループのチーム上での一意な名前を表します。 */
        url_name: string;
    }
    interface Comment {
        /** コメントの内容を表すMarkdown形式の文字列 */
        body: string;
        /** データが作成された日時 */
        created_at: string;
        /** コメントの一意なID */
        id: string;
        /** コメントの内容を表すHTML形式の文字列 */
        rendered_body: string;
        /** データが最後に更新された日時 */
        updated_at: string;
        /** Qiita上のユーザを表します。 */
        user: User;
    }
    interface Tagging {
        /** タグを特定するための一意な名前 */
        name: string;
        /** (説明無し) */
        versions: string[];
    }
    interface Tag {
        /** このタグをフォローしているユーザの数 */
        followers_count: number;
        /** このタグに設定されたアイコン画像のURL */
        icon_url?: string;
        /** タグを特定するための一意な名前 */
        id: string;
        /** このタグが付けられた投稿の数 */
        items_count: number;
    }
    interface Team {
        /** チームが利用可能な状態かどうか */
        active: boolean;
        /** チームの一意なID */
        id: string;
        /** チームに設定されている名前を表します。 */
        name: string;
    }
    interface Template {
        /** テンプレートの本文 */
        body: string;
        /** テンプレートの一意なID */
        id: number;
        /** テンプレートを判別するための名前 */
        name: string;
        /** 変数を展開した状態の本文 */
        expanded_body: string;
        /** 変数を展開した状態のタグ一覧 */
        expanded_tags: Tagging[];
        /** 変数を展開した状態のタイトル */
        expanded_title: string;
        /** タグ一覧 */
        tags: Tagging[];
        /** 生成される投稿のタイトルの雛形 */
        title: string;
    }
    interface Project {
        /** HTML形式の本文 */
        rendered_body: string;
        /** このプロジェクトが進行中かどうか */
        archived: boolean;
        /** Markdown形式の本文 */
        body: string;
        /** データが作成された日時 */
        created_at: string;
        /** プロジェクトのチーム上での一意なID */
        id: number;
        /** プロジェクト名 */
        name: string;
        /** 絵文字リアクション数 */
        reactions_count: number;
        /** データが最後に更新された日時 */
        updated_at: string;
    }
    interface User {
        /** 自己紹介文 */
        description?: string;
        /** Facebook ID  */
        facebook_id?: string;
        /** このユーザがフォローしているユーザの数  */
        followees_count: number;
        /** このユーザをフォローしているユーザの数 */
        followers_count: number;
        /** GitHub ID */
        github_login_name?: string;
        /** ユーザID */
        id: string;
        /** このユーザが qiita.com 上で公開している投稿の数 (Qiita:Teamでの投稿数は含まれません) */
        items_count: number;
        /** LinkedIn ID */
        linkedin_id?: string;
        /** 居住地 */
        location?: string;
        /** 設定している名前 */
        name?: string;
        /** 所属している組織 */
        organization?: string;
        /** ユーザごとに割り当てられる整数のID */
        permanent_id: number;
        /** 設定しているプロフィール画像のURL */
        profile_image_url: string;
        /** Twitterのスクリーンネーム */
        twitter_screen_name?: string;
        /** 設定しているWebサイトのURL */
        website_url?: string;
    }
    interface ExpandedTemplate {
        /** 変数を展開した状態の本文 */
        expanded_body: string;
        /** 変数を展開した状態のタグ一覧 */
        expanded_tags: Tagging[];
        /** 変数を展開した状態のタイトル */
        expanded_title: string;
    }
    interface Item {
        /** HTML形式の本文 */
        rendered_body: string;
        /** Markdown形式の本文 */
        body: string;
        /** この投稿が共同更新状態かどうか (Qiita:Teamでのみ有効) */
        coediting: boolean;
        /** この投稿へのコメントの数 */
        comments_count: number;
        /** データが作成された日時 */
        created_at: string;
        /** Qiita:Teamのグループを表します。 */
        group: Group;
        /** 投稿の一意なID */
        id: string;
        /** この投稿への「いいね！」の数（Qiitaでのみ有効） */
        likes_count: number;
        /** 限定共有状態かどうかを表すフラグ (Qiita:Teamでは無効) */
        private: boolean;
        /** 投稿に付いたタグ一覧 */
        tags: Tagging[];
        /** 投稿のタイトル */
        title: string;
        /** データが最後に更新された日時 */
        updated_at: string;
        /** 投稿のURL */
        url: string;
        /** Qiita上のユーザを表します。 */
        user: User;
        /** 閲覧数 */
        page_views_count: number;
    }
    interface TeamInvitation {
        /** 招待中のメンバーのemailアドレスです。 */
        email: string;
        /** 招待用URLです。有効期限は1日です。 */
        url: string;
    }
    interface Reaction {
        /** データが作成された日時 */
        created_at: string;
        /** 絵文字画像のURL */
        image_url: string;
        /** 絵文字の識別子 */
        name: string;
        /** Qiita上のユーザを表します。 */
        user: User;
    }
    interface AuthenticatedUser extends User {
        /** 1ヶ月あたりにQiitaにアップロードできる画像の総容量 */
        image_monthly_upload_limit: number;
        /** その月にQiitaにアップロードできる画像の残りの容量 */
        image_monthly_upload_remaining: number;
        /** Qiita:Team専用モードに設定されているかどうか */
        team_only: boolean;
    }
}
export declare class Qiita {
    private token;
    private endpoint;
    private version;
    /**
     * Qiita APIにアクセスするためのトークンを設定します
     * @param token トークン文字列
     * @return 何も返しません
     */
    setToken(token: string): void;
    /**
     * Qiita Teamへのエンドポイントを設定します
     * @param endpoint エンドポイントへのURI
     * @return 何も返しません
     */
    setEndpoint(endpoint: string): void;
    /**
     * Qiita APIへのパスを指定します．
     * @param version APIへのパスの文字列 (e.g. `/api/v2`)
     * @return 何も返しません
     */
    setVersion(version: string): void;
    /**
     * Fetch APIのラッパー関数です．
     * 環境依存で `window.fetch` と `node-fetch` を切り替えます
     * @param url `fetch()` の第一引数です
     * @param options `fetch()` の第二引数です
     * @return レスポンスをパースしたリテラル/オブジェクトを返すPromiseを返します
     */
    protected request: (url: string, options?: any) => Promise<any>;
    /**
     * HTTP GET のラッパー関数です
     * @param url リクエストのエンドポイントです
     * @param params オブジェクトを指定すると，query stringに文字列化してURLの末尾に付与します
     * @param options `fetch()` の第二引数です
     * @return レスポンスをパースしたリテラル/オブジェクトを返すPromiseを返します
     */
    protected get: (url: string, params?: {}, options?: {}) => Promise<any>;
    /**
     * HTTP POST のラッパー関数です
     * @param url リクエストのエンドポイントです
     * @param params オブジェクトを指定すると，JSON文字列化してbodyに付与します
     * @param options `fetch()` の第二引数です
     * @return レスポンスをパースしたリテラル/オブジェクトを返すPromiseを返します
     */
    protected post: (url: string, body?: {}, options?: {}) => Promise<any>;
    /**
     * HTTP PUT のラッパー関数です
     * @param url リクエストのエンドポイントです
     * @param params オブジェクトを指定すると，JSON文字列化してbodyに付与します
     * @param options `fetch()` の第二引数です
     * @return レスポンスをパースしたリテラル/オブジェクトを返すPromiseを返します
     */
    protected put: (url: string, body?: {}, options?: {}) => Promise<any>;
    /**
     * HTTP DELETE のラッパー関数です
     * @param url リクエストのエンドポイントです
     * @param params オブジェクトを指定すると，JSON文字列化してbodyに付与します
     * @param options `fetch()` の第二引数です
     * @return レスポンスをパースしたリテラル/オブジェクトを返すPromiseを返します
     */
    protected delete: (url: string, body?: {}, options?: {}) => Promise<any>;
    /**
     * HTTP PATCH のラッパー関数です
     * @param url リクエストのエンドポイントです
     * @param params オブジェクトを指定すると，JSON文字列化してbodyに付与します
     * @param options `fetch()` の第二引数です
     * @return レスポンスをパースしたリテラル/オブジェクトを返すPromiseを返します
     */
    protected patch: (url: string, body?: {}, options?: {}) => Promise<any>;
    /**
     * 与えられた認証情報をもとに新しいアクセストークンを発行します。
     * @param clientId 登録されたAPIクライアントを特定するためのID
     * @param clientSecret 登録されたAPIクライアントを認証するための秘密鍵
     * @param code リダイレクト用のURLに付与された、アクセストークンと交換するための文字列
     * @return アクセストークン
     */
    fetchAccessToken: (clientId: string, clientSecret: string, code: string) => Promise<Qiita.AccessToken>;
    /**
     * 指定されたアクセストークンを失効させ、それ以降利用できないようにします。
     * @param token アクセストークン
     * @return 空のオブジェクト
     */
    deleteAccessToken: (token: string) => Promise<{}>;
    /**
     * コメントを取得します。
     * @param commentId コメントのID
     * @return コメントのエンティティを返します
     */
    fetchComment: (commentId: string) => Promise<Qiita.Comment>;
    /**
     * コメントを更新します。
     * @param commentId コメントのID
     * @param body コメントの内容を表すMarkdown形式の文字列
     */
    updateComment: (commentId: string, body: string) => Promise<Qiita.Comment>;
    /**
     * コメントを削除します。
     * @param commentId コメントのID
     * @return 空のオブジェクト
     */
    deleteComment: (commentId: string) => Promise<{}>;
    /**
     * コメントに付けられた絵文字リアクション一覧を作成日時の降順で返します。
     * @param commentId コメントID
     * @return 絵文字リアクション
     */
    fetchCommentReactions: (commentId: string) => Promise<Qiita.Reaction[]>;
    /**
     * コメントに絵文字リアクションを付けます。
     * @param commentId コメントID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    createCommentReaction: (commentId: string, name: string) => Promise<Qiita.Reaction>;
    /**
     * コメントから絵文字リアクションを削除します。
     * @param commentId コメントID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    deleteCommentReaction: (commentId: string, name: string) => Promise<Qiita.Reaction>;
    /**
     * タグ一覧を作成日時の降順で返します。
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @param sort 並び順 (countで投稿数順、nameで名前順)
     * @return タグ一覧
     */
    fetchTags: (page: string, perPage: string, sort: string) => Promise<Qiita.Tag[]>;
    /**
     * タグを取得します。
     * @param tagId タグのID
     * @return タグ
     */
    fetchTag: (tagId: string) => Promise<Qiita.Tag>;
    /**
     * タグをフォローしているかどうかを調べます。
     * @param tagId タグのID
     * @return タグ
     */
    checkIfFollowingTag: (tagId: string) => Promise<Qiita.Tag>;
    /**
     * タグをフォローします。
     * @param tagId タグのID
     * @return 空のオブジェクト
     */
    followTag: (tagId: string) => Promise<Qiita.Tag>;
    /**
     * タグをフォローします。
     * @param tagId タグのID
     * @return 空のオブジェクト
     */
    unfollowTag: (tagId: string) => Promise<{}>;
    /**
     * 指定されたタグが付けられた投稿一覧を、タグを付けた日時の降順で返します。
     * @param tagId タグID
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return 投稿一覧
     */
    fetchTaggedItems: (tagId: string, page: string, perPage: string) => Promise<Qiita.Item[]>;
    /**
     * チーム内のテンプレート一覧を返します。
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return テンプレート一覧
     */
    fetchTemplates: (page: string, perPage: string) => Promise<Qiita.Template[]>;
    /**
     * テンプレートを取得します。
     * @param tempalteId テンプレートID
     * @return テンプレート
     */
    fetchTempalte: (templateId: string) => Promise<Qiita.Template>;
    /**
     * 新しくテンプレートを作成します。
     * @param body テンプレートの本文
     * @param name テンプレートを判別するための名前
     * @param tags タグ一覧
     * @param title 生成される投稿のタイトルの雛形
     * @return テンプレート
     */
    createTemplate: (body: string, name: string, tags: Qiita.Tagging[], title: string) => Promise<Qiita.Template>;
    /**
     * テンプレートを更新します。
     * @param body テンプレートの本文
     * @param name テンプレートを判別するための名前
     * @param tags タグ一覧
     * @param title 生成される投稿のタイトルの雛形
     * @return テンプレート
     */
    updateTempalte: (body: string, name: string, tags: Qiita.Tagging[], title: string) => Promise<Qiita.Template>;
    /**
     * テンプレートを削除します。
     * @param templateId テンプレートID
     * @return 空のオブジェクト
     */
    deleteTemplate: (templateId: string) => Promise<{}>;
    /**
     * チーム内に存在するプロジェクト一覧をプロジェクト作成日時の降順で返します。
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return プロジェクト一覧
     */
    fetchProjects: (page: string, perPage: string) => Promise<Qiita.Project[]>;
    /**
     * プロジェクトを返します。
     * @param projectId プロジェクトID
     * @return プロジェクト
     */
    fetchProject: (projectId: string) => Promise<Qiita.Project>;
    /**
     * プロジェクトを新たに作成します。
     * @param archived このプロジェクトが進行中かどうか
     * @param body Markdown形式の本文
     * @param name プロジェクト名
     * @param tags 投稿に付いたタグ一覧
     * @return プロジェクト
     */
    createProject: (archived: boolean, body: string, name: string, tags: Qiita.Tagging[]) => Promise<Qiita.Project>;
    /**
     * プロジェクトを更新します。
     * @param archived このプロジェクトが進行中かどうか
     * @param body Markdown形式の本文
     * @param name プロジェクト名
     * @param tags 投稿に付いたタグ一覧
     * @return プロジェクト
     */
    updateProject: (archived: boolean, body: string, name: string, tags: Qiita.Tagging[]) => Promise<Qiita.Project>;
    /**
     * プロジェクトを削除します。
     * @param projectId プロジェクトID
     * @return 空のオブジェクト
     */
    deleteProject: (projectId: string) => Promise<{}>;
    /**
     * プロジェクトに付けられたコメント一覧を投稿日時の降順で取得します。
     * @param projectId プロジェクトのID
     * @return コメント一覧
     */
    fetchProjectComments: (projectId: string) => Promise<Qiita.Comment[]>;
    /**
     * プロジェクトに対してコメントを投稿します。
     * @param projectId 投稿のID
     * @param body コメントの内容を表すMarkdown形式の文字列
     * @return 投稿したコメント
     */
    createProjectComment: (projectId: string, body: string) => Promise<Qiita.Comment[]>;
    /**
     * プロジェクトに付けられた絵文字リアクション一覧を作成日時の降順で返します。
     * @param projectId プロジェクトID
     * @return 絵文字リアクション一覧
     */
    fetchProjectReactions: (projectId: string) => Promise<Qiita.Reaction[]>;
    /**
     * プロジェクトに絵文字リアクションを付けます。
     * @param projectId プロジェクトID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    createProjectReaction: (projectId: string, name: string) => Promise<Qiita.Reaction>;
    /**
     * プロジェクトから絵文字リアクションを削除します。
     * @param projectId プロジェクトID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    deleteProjectReaction: (projectId: string, name: string) => Promise<Qiita.Reaction>;
    /**
     * 全てのユーザの一覧を作成日時の降順で取得します。
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return ユーザー一覧
     */
    fetchUsers: (page: string, perPage: string) => Promise<Qiita.User[]>;
    /**
     * ユーザを取得します。
     * @param userId ユーザーID
     * @return ユーザー
     */
    fetchUser: (userId: string) => Promise<Qiita.User>;
    /**
     * ユーザがフォローしているユーザ一覧を取得します。
     * @param userId ユーザーID
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return ユーザー一覧
     */
    fetchUserFollowees: (userId: string, page: string, perPage: string) => Promise<Qiita.User[]>;
    /**
     * ユーザをフォローしているユーザ一覧を取得します。
     * @param userId ユーザーID
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return ユーザー一覧
     */
    fetchUserFollowers: (userId: string, page: string, perPage: string) => Promise<Qiita.User[]>;
    /**
     * 指定されたユーザの投稿一覧を、作成日時の降順で返します。
     * @param userId ユーザID
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return 投稿一覧
     */
    fetchUserItems: (userId: string, page: string, perPage: string) => Promise<Qiita.Item[]>;
    /**
     * 指定されたユーザがストックした投稿一覧を、ストックした日時の降順で返します。
     * @param userId ユーザID
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return 投稿一覧
     */
    fetchUserStocks: (userId: string, page: string, perPage: string) => Promise<Qiita.Item[]>;
    /**
     * ユーザがフォローしているタグ一覧をフォロー日時の降順で返します。
     * @param userId ユーザーID
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return タグ一覧
     */
    fetchUserFollowingTags: (userId: string, page: string, perPage: string) => Promise<Qiita.Tag[]>;
    /**
     * ユーザをフォローしている場合に204を返します。
     * @param userId ユーザーID
     * @return 空のオブジェクト
     */
    checkIfFollowingUser: (userId: string) => Promise<{}>;
    /**
     * ユーザをフォローします
     * @param userId ユーザーID
     * @return 空のオブジェクト
     */
    followUser: (userId: string) => Promise<{}>;
    /**
     * ユーザへのフォローを外します。
     * @param userId ユーザーID
     * @return 空のオブジェクト
     */
    unfollowUser: (userId: string) => Promise<{}>;
    /**
     * 投稿の一覧を作成日時の降順で返します。
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @param query 検索クエリ
     * @return 投稿一覧
     */
    fetchItems: (page: string, perPage: string, query: string) => Promise<Qiita.Item[]>;
    /**
     * 投稿を取得します。
     * @param itemId 投稿ID
     * @return 投稿
     */
    fetchItem: (itemId: string) => Promise<Qiita.Item>;
    /**
     * 新たに投稿を作成します。
     * @param params.body Markdown形式の本文
     * @param params.coediting この投稿が共同更新状態かどうか (Qiita:Teamでのみ有効)
     * @param params.gist 本文中のコードをGistに投稿するかどうか (GitHub連携を有効化している場合のみ有効)
     * @param params.groupUrlName この投稿を公開するグループの url_name (null で全体に公開。Qiita:Teamでのみ有効)
     * @param params.private 限定共有状態かどうかを表すフラグ (Qiita:Teamでは無効)
     * @param params.tag 投稿に付いたタグ一覧
     * @param params.title 投稿のタイトル
     * @param params.tweet Twitterに投稿するかどうか (Twitter連携を有効化している場合のみ有効)
     * @return 投稿
     */
    createItem: (params: {
        body: string;
        coediting: boolean;
        gist: boolean;
        groupUrlName?: string | null | undefined;
        private: boolean;
        tags: Qiita.Tagging;
        title: string;
        tweet: boolean;
    }) => Promise<Qiita.Item>;
    /**
     * 投稿を更新します。
     * @param itemId 投稿のID
     * @param params.coediting この投稿が共同更新状態かどうか (Qiita:Teamでのみ有効)
     * @param params.groupUrlName この投稿を公開するグループの url_name (null で全体に公開。Qiita:Teamでのみ有効)
     * @param params.private 限定共有状態かどうかを表すフラグ (Qiita:Teamでは無効)
     * @param params.tag 投稿に付いたタグ一覧
     * @param params.title 投稿のタイトル
     * @return 投稿
     */
    updateItem: (itemId: string, params: {
        body: string;
        coediting: boolean;
        groupUrlName?: string | null | undefined;
        private: boolean;
        tags: Qiita.Tagging;
        title: string;
    }) => Promise<Qiita.Item>;
    /**
     * 投稿を削除します。
     * @param itemId 投稿ID
     * @return 空のオブジェクト
     */
    deleteItem: (itemId: string) => Promise<{}>;
    /**
     * 投稿に「いいね！」を付けているかどうかを調べます。
     * @param itemId 投稿ID
     * @return 空のオブジェクト
     */
    checkIfLikedItem: (itemId: string) => Promise<{}>;
    /**
     * 投稿に「いいね！」を付けます。
     * @param itemId 投稿ID
     * @return 空のオブジェクト
     */
    likeItem: (itemId: string) => Promise<{}>;
    /**
     * 投稿への「いいね！」を取り消します。
     * @param itemId 投稿ID
     * @return 空のオブジェクト
     */
    unlikeItem: (itemId: string) => Promise<{}>;
    /**
     * 投稿をストックしているかどうかを調べます。
     * @param itemId 投稿ID
     * @return 空のオブジェクト
     */
    checkIfStockedItem: (itemId: string) => Promise<{}>;
    /**
     * 投稿をストックします。
     * @param itemId 投稿ID
     * @return 空のオブジェクト
     */
    stockItem: (itemId: string) => Promise<{}>;
    /**
     * 投稿をストックから取り除きます。
     * @param itemId 投稿ID
     * @return 空のオブジェクト
     */
    unstockItem: (itemId: string) => Promise<{}>;
    /**
     * 記事に付けられた絵文字リアクション一覧を作成日時の降順で返します。
     * @param itemId 投稿ID
     * @return 絵文字リアクション
     */
    fetchItemReactions: (itemId: string) => Promise<Qiita.Reaction[]>;
    /**
     * 記事に絵文字リアクションを付けます。
     * @param itemId 投稿ID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    createItemReaction: (itemId: string, name: string) => Promise<Qiita.Reaction>;
    /**
     * 記事から絵文字リアクションを削除します。
     * @param itemId 投稿ID
     * @param name 絵文字の識別子
     * @return 絵文字リアクション
     */
    deleteItemReaction: (itemId: string, name: string) => Promise<Qiita.Reaction>;
    /**
     * 投稿につけられた「いいね！」を作成日時の降順で返します。
     * @param itemId 投稿のID
     * @return いいね！エンティティを返します
     */
    fetchItemLikes: (itemId: string) => Promise<Qiita.Like[]>;
    /**
     * 投稿をストックしているユーザ一覧を、ストックした日時の降順で返します。
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return ユーザー一覧
     */
    fetchItemStockers: (itemId: string, page: string, perPage: string) => Promise<Qiita.User[]>;
    /**
     * 投稿に付けられたコメント一覧を投稿日時の降順で取得します。
     * @param itemId 投稿のID
     * @return コメント一覧
     */
    fetchItemComments: (itemId: string) => Promise<Qiita.Comment[]>;
    /**
     * 投稿に対してコメントを投稿します。
     * @param itemId 投稿のID
     * @param body コメントの内容を表すMarkdown形式の文字列
     * @return 投稿したコメント
     */
    createItemComment: (itemId: string, body: string) => Promise<Qiita.Comment[]>;
    /**
     * 投稿にタグを追加します。Qiita:Teamでのみ有効です。
     * @param itemId 投稿のID
     * @param name タグを特定するための一意な名前
     * @param versions (説明なし)
     */
    addItemTag: (itemId: string, name: string, versions: string[]) => Promise<Qiita.Tagging>;
    /**
     * 投稿から指定されたタグを取り除きます。Qiita:Teamでのみ有効です。
     * @param itemId 投稿のID
     * @param tagId タギングのID
     * @return 空のオブジェクト
     */
    removeItemTag: (itemId: string, tagId: string) => Promise<{}>;
    /**
     * ユーザが所属している全てのチームを、チーム作成日時の降順で返します。
     * @return チーム一覧
     */
    fetchTeams: () => Promise<Qiita.Team[]>;
    /**
     * 招待中のメンバーの一覧を返します
     * @return 招待
     */
    fetchTeamInvitations: () => Promise<Qiita.TeamInvitation>;
    /**
     * チームにメンバーを招待します
     * @return 招待
     */
    createTeamInvitations: () => Promise<Qiita.TeamInvitation>;
    /**
     * 招待を取り消します
     * @return 空のオブジェクト
     */
    deleteTeamInvitation: () => Promise<{}>;
    /**
     * アクセストークンに紐付いたユーザを返します。
     * @return 認証中のユーザ
     */
    fetchMe: () => Promise<Qiita.AuthenticatedUser>;
    /**
     * 認証中のユーザの投稿の一覧を作成日時の降順で返します。
     * @param page ページ番号 (1から100まで)
     * @param perPage 1ページあたりに含まれる要素数 (1から100まで)
     * @return 投稿一覧
     */
    fetchMyItems: (page: string, perPage: string) => Promise<Qiita.Item[]>;
}
